NumBuffer

Struct NumBuffer 

1.98.0 · Source
pub struct NumBuffer<T: NumBufferTrait> {
    pub(crate) buf: T::Buf,
    phantom: PhantomData<T>,
}
A buffer wrapper of which the internal size is based on the maximum number of digits the associated integer can have.

Examples

use core::fmt::NumBuffer;

let mut buf = NumBuffer::new();
let n1 = 1972u32;
assert_eq!(n1.format_into(&mut buf), "1972");

// Formatting a negative integer includes the sign.
let mut buf = NumBuffer::new();
let n2 = -1972i32;
assert_eq!(n2.format_into(&mut buf), "-1972");

Fields

buf: T::Bufphantom: PhantomData<T>

Implementations

1.98.0 · Source

impl<T: NumBufferTrait> NumBuffer<T>

1.98.0 (const: 1.98.0) · Source

pub const fn new() -> Self

Initializes internal buffer.